@@ -114,6 +114,8 @@ def handle_get(path):
 # 处理 HEAD 请求
 def handle_head(path):
     local_path = utils.get_local_path(path)
+    if not os.path.exists(local_path):
+        utils.fetch_from_remote(path)
     if os.path.exists(local_path):
         return Response(headers={'Content-Length': os.path.getsize(local_path)})
     abort(404)
@@ -222,7 +224,7 @@ def startup():
     print(f"repo_context_path={app.config['REPO_CONTEXT_PATH']}")
     print(f"browse_context_path={app.config['BROWSE_CONTEXT_PATH']}")
     print(f"local_repo_dir={config.REPO_ROOT}")
-    print(f"remote_repo={config.REMOTE_REPO}")
+    print(f"remote_repo={config.REMOTE_REPOS}")
     # 初始化定时任务
     job.start()
     app.run(host='0.0.0.0', port=config.PORT, threaded=True)
